; Nullsoft Scriptable Install System (NSIS) script file

!define VERSION "1.1.1"
Name "ViCompress ${VERSION}"
InstallDir "$PROGRAMFILES\ViCompress"
InstallDirRegKey HKLM "Software\ViCompress" "installdir"
OutFile "vicompress-${VERSION}.installer.exe"
Icon visolvelogo.ico
AddBrandingImage top 65 5
XPStyle on
WindowIcon off

; The Pages (Screens) to display during the install/uninstall sequence
Page directory "" setlogo ""
Page instfiles
UninstPage uninstConfirm "" un.setlogo ""
UninstPage instfiles

; The text to display in the Uninstall confirmation page
UninstallText "This wizard will uninstsall ViCompress 1.1.1 from your \
computer. It will delete all files under the ViCompress install \
directory, including log files and log statistics.  Click Uninstall to \
start the uninstallation." "Uninstalling from:"


; Function CreateConf()
; Create the configuration file vicompress.conf.txt under the $INSTDIR
; We can't use a pre-defined vicompress.conf.txt file, because we don't
; know the install directory where the logs will be located. So we must
; generate the file at install time.

Function CreateConf

  FileOpen $1 $INSTDIR\vicompress.conf.txt w
  FileWrite $1 "# ViCompress configuration file$\r$\n$\r$\n"
  FileWrite $1 "# webserver 127.0.0.1 81   # Forward requests to single webserver (optional)$\r$\n"
  FileWrite $1 "# hostheader domainname    # Set the Host: header to the given domain name $\r$\n"
  FileWrite $1 "listen 0.0.0.0 80          # IP address and port to listen on$\r$\n"
  FileWrite $1 "outgoingip 0.0.0.0         # IP address to bind to for outgoing connections$\r$\n"
  FileWrite $1 "enable_sessions yes        # Enable sticky sessions with multiple webservers$\r$\n"
  FileWrite $1 "enable_compression yes     # Enable compression of html/text pages$\r$\n"
  FileWrite $1 "enable_caching yes         # Enabling caching of web pages/images$\r$\n"
  FileWrite $1 "cache_memory 200           # Amount of memory used for cache, in megabytes $\r$\n"
  FileWrite $1 "max_cacheditem_size 512    # Max size of cached items, in kilobytes$\r$\n"
  FileWrite $1 "cache_expires 240          # How long a cached page is valid (in hours) $\r$\n"
  FileWrite $1 "enable_dns_caching yes     # Enable caching of dns lookups$\r$\n"
  FileWrite $1 "dns_expires 2              # How long cached dns lookups are valid (in hours)$\r$\n"
  FileWrite $1 "rotatesize 100             # Size (in megabytes) at which to rotate log files$\r$\n"
  FileWrite $1 "logformat squid            # Format of access log (apache or squid)$\r$\n"
  FileWrite $1 "enable_debug no            # Enable debug messages in the errorlog$\r$\n"
  FileWrite $1 "accesslog $\"$INSTDIR\log\accesslog.txt$\" # Access log file path$\r$\n"
  FileWrite $1 "errorlog  $\"$INSTDIR\log\errorlog.txt$\"  # Error log file path$\r$\n"
  FileWrite $1 "errorpage $\"$INSTDIR\errorpage.html$\"    # HTML page for errors$\r$\n"
  FileWrite $1 "logstats  $\"$INSTDIR\logstats$\"          # Log statistics directory$\r$\n"
  FileClose $1

FunctionEnd

; Display the visolve logo in the installer screens
Function setlogo
  GetTempFileName $0
  File /oname=$0 "visolvelogo.bmp"
  SetBrandingImage /RESIZETOFIT $0
  Delete $0
FunctionEnd 

; Display the visolve logo in the uninstaller screens
Function un.setlogo
  GetTempFileName $0
  File /oname=$0 "visolvelogo.bmp"
  SetBrandingImage /RESIZETOFIT $0
  Delete $0
FunctionEnd 

; Set $already_installed = "true" if ViCompress is already installed
; Install the following files/directories under $INSTDIR
;   vicompress.exe
;   update_log_stats.exe
;   vicompress_manual.html
;   errorpage.html
;   LICENSE.txt
;   vicompress.conf.txt (only if it doesn't already exist)
;   log
;   logstats\verticalbarN.png
;   logstats\visolvelogo.gif
;   logstats\template.html
; Create the uninstall program uninstall.exe
; Add ViCompress as a service by calling
;   vicompress.exe -i $INSTALLDIR
; Install Menu shortcuts for
;   vicompress.conf.txt
;   ViCompress Manual
;   uninstall.exe

Section "ViCompress ${VERSION} (required)"
  SectionIn RO
  SetOutPath $INSTDIR
  Var /GLOBAL already_installed
  StrCpy $already_installed "false"
  IfFileExists $INSTDIR\vicompress.exe +2 0
  StrCpy $already_installed "true"

  File ..\src\vicompress.exe
  File ..\src\update_log_stats.exe
  File ..\docs\vicompress_manual.html
  File ..\docs\*.png
  File ..\src\errorpage.html
  File LICENSE.txt
  IfFileExists $INSTDIR\vicompress.conf.txt +2 0
  Call CreateConf

  CreateDirectory $INSTDIR\log
  CreateDirectory $INSTDIR\logstats
  SetOutPath $INSTDIR\logstats
  File ..\logstats\*.png
  File ..\logstats\*.html
  File ..\logstats\*.gif

  WriteRegStr HKLM SOFTWARE\ViCompress "installdir" "$INSTDIR"
  WriteRegStr HKLM SOFTWARE\ViCompress "version" "${VERSION} $already_installed"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\ViCompress" "DisplayName" "ViCompress"
  WriteUninstaller "uninstall.exe"

  ; If ViCompress is already installed (if this is an upgrade rather
  ; than a fresh install), then skip  installing ViCompress as a service.
  StrCmp $already_installed "true" 0 +2
  Exec "$INSTDIR\vicompress.exe -i $\"$INSTDIR$\""

  CreateDirectory "$SMPROGRAMS\ViCompress"
  
  CreateShortCut "$SMPROGRAMS\ViCompress\ViCompress Service.lnk" "$SYSDIR\services.msc" "" "$SYSDIR\services.msc" 0
  CreateShortCut "$SMPROGRAMS\ViCompress\ViCompress Manual.lnk" "$INSTDIR\vicompress_manual.html" "" "$INSTDIR\vicompress_manual.html" 0
  CreateShortCut "$SMPROGRAMS\ViCompress\vicompress.conf.txt config file.lnk" "$INSTDIR\vicompress.conf.txt" "" "$INSTDIR\vicompress.conf.txt" 0
  CreateShortCut "$SMPROGRAMS\ViCompress\Log Files.lnk" "$INSTDIR\log" "" "$INSTDIR\log" 0
  CreateShortCut "$SMPROGRAMS\ViCompress\Log Statistics.lnk" "$INSTDIR\logstats" "" "$INSTDIR\logstats" 0
  CreateShortCut "$SMPROGRAMS\ViCompress\uninstall.lnk" "$INSTDIR\uninstall.exe" "" "$INSTDIR\uninstall.exe" 0


SectionEnd

; Uninstall vicompress
;   Delete the ViCompress Windows Service
;   Delete the registry keys
;   Delete the ViCompress install files/directory
;   Delete the ViCompress start menu links
Section "Uninstall"
  Exec "$INSTDIR\vicompress.exe -u"
  Sleep 500
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\ViCompress"
  DeleteRegKey HKLM SOFTWARE\ViCompress
  Delete $INSTDIR\*.*
  Delete $INSTDIR\log\*.*
  Delete $INSTDIR\logstats\*.*
  RMDir  "$INSTDIR\log"
  RMDir  "$INSTDIR\logstats"
  RMDir  "$INSTDIR"
  Delete $SMPROGRAMS\ViCompress\*.*
  RMDir  "$SMPROGRAMS\ViCompress"
SectionEnd


