/*
 * Copyright (c) 2003-2008 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef _BUFFER_H_
#define _BUFFER_H_

#include <time.h>
#include "pool.h"

/* 
 * A Substring represents a smaller string in a
 * large character buffer. 
 */
struct _Substring
{
    const char *buf;
    int size;
};
typedef struct _Substring Substring;

typedef struct _BufferPool BufferPool;

/* 
 * A buffer is a reference-counted character buffer.
 * The character arrays it uses are allocated from
 * buffer pools.
 */
struct _Buffer 
{
    char *buf;               /* The character array of data */
    int size;                /* The size of data in the array */
    int capacity;            /* The size of the array */
    int refcount;            /* The reference count */
    BufferPool *pool;        /* The pool this buffer belongs to */
};
typedef struct _Buffer Buffer;

/* A pool to allocate Buffers from */
struct _BufferPool
{
    Pool bufpool;        /* pool of byte arrays */
    Pool buffer;         /* pool of Buffer structures */
    int size;            /* The size of the buf */
};

void bufferpool_init(BufferPool *bp, int size, long count); 
int bufferpool_is_empty(BufferPool *bp);
Buffer* buffer_alloc(BufferPool *bp);
Buffer* buffer_ref(Buffer *b);
void buffer_unref(Buffer *b);
void buffer_add(Buffer *buffer, const char *data, int size);
void buffer_add_int(Buffer *buffer, int x);
void buffer_reset(Buffer *buffer);
void buffer_grow(Buffer *buffer, int size);

#endif

