/*
 * Copyright (c) 2009 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef _CHUNKED_H_
#define _CHUNKED_H_

#include "buffer.h"
#include "conf.h"

/* Info needed for tracking chunked-encoding transfers. */
struct _ChunkedTransfer {
    int state;         /* state of chunked transfer */
    int chunk_size;    /* The size of the current chunk */
    int chunk_left;    /* The number of bytes still needed for this chunk */
    int buffer_end;    /* The buffer offset where the chunked reply ends */
};
typedef struct _ChunkedTransfer ChunkedTransfer;

/* ChunkedTransfer states */
#define CHUNKED_STATE_READ_SIZE    0 /* Waiting to read the chunk size */
#define CHUNKED_STATE_READ_BODY    1 /* Waiting to read chunk body data */
#define CHUNKED_STATE_READ_NEWLINE 2 /* Waiting to read \r\n after body */

/* Return values for chunked_parse() */
#define CHUNKED_ERROR    1  /* Error parsing chunked-encoding */
#define CHUNKED_DONE     2  /* Chunked transfer is done */
#define CHUNKED_PARTIAL  3  /* Chunked transfer still in progress */
#define CHUNKED_READSIZE 4  /* Need to read more data to get chunk size */

void chunked_init(ChunkedTransfer *c);
int  chunked_is_done(ChunkedTransfer *c, Buffer *buffer);
int  chunked_decode(ChunkedTransfer *c, Buffer *input, Buffer *out);


#define CHUNKED_HEADERSIZE   6 /* Size of chunk header (<hexsize>\r\n) */

void chunk_encode_start(Buffer *b);
void chunk_encode_end(Buffer *b);

#endif

