#! /bin/sh

# Create various vicompress.conf files.  Check to see that
# 1. Valid values do not produce any error messages
# 2. Invalid values do produce error messages

mkdir tmpdir >/dev/null 2>/dev/null

count=1
error=0

echo "
listen                  127.0.0.1 80
listen                  127.0.0.1 81
outgoingip              127.0.0.1
webserver               15.13.114.43 80
webserver               15.13.114.43 81 host.com host2.com
enable_sessions         yes
enable_compression      yes
enable_caching          yes
cache_memory            20
max_cacheditem_size     150
cache_expires           14
enable_dns_caching      yes
dns_expires             48
user                    nobody
hostheader              domain.com
logformat               apache
accesslog               access_log
errorlog                error_log
logstats                tmpdir
errorpage               errorpage.html
rotatesize              100
enable_debug            yes
" > testconfig

./conftest testconfig 2>&1 | grep ERROR 
if [ $? = 0 ]
then
  echo "conftest ERROR: test $count. Expected no errors, got some."
  error=1
fi
rmdir tmpdir
 
count=2
echo "
logformat              squid
enable_caching         no
enable_compression     no
enable_dns_caching     no
enable_sessions        no
enable_debug           no
" > testconfig

./conftest testconfig 2>&1 | grep ERROR > /dev/null
if [ $? = 0 ]
then
  echo "conftest ERROR: test $count. Expected no errors, got some."
  error=1
fi

count=3
echo "
    # no arguments
listen
outgoingip
webserver
enable_sessions
enable_compression
enable_caching
cache_memory
max_cacheditem_size
cache_expires
enable_dns_caching
dns_expires
user
hostheader
logformat
accesslog
errorlog
logstats
errorpage
rotatesize
enable_debug
" > testconfig

num=`./conftest testconfig 2>&1 | grep ERROR | wc -l`
if [ $num != 20 ]
then
  echo "conftest ERROR: test $count. Expected 20 config errors, got $num."
  error=1
fi

count=4
echo "
listen                  unknown 80
outgoingip              unknown
webserver               unknown 80
enable_sessions         unknown
enable_compression      unknown
enable_caching          unknown
cache_memory            unknown
max_cacheditem_size     unknown
cache_expires           unknown
enable_dns_caching      unknown
dns_expires             unknown
user                    unknown2
logstats                unknown
logformat               unknown
rotatesize              unknown
errorpage               unknown
somedirective           unknown
enable_debug            unknown
" > testconfig

num=`./conftest testconfig 2>&1 | grep ERROR | wc -l`
if [ $num != 18 ]
then
  echo "conftest ERROR: test $count. Expected 18 config errors, got $num. "
  error=1
fi

count=5
echo "
listen    127.0.0.1 999999
webserver 127.0.0.1 999999
max_cacheditem_size  -1
cache_expires  -1
dns_expires  -1
rotatesize  0
" > testconfig

num=`./conftest testconfig 2>&1 | grep ERROR |wc -l`
if [ $num != 6 ]
then
  echo "conftest ERROR: test $count. Expected 6 errors, got $num."
  error=1
fi

count=6
echo "" > testconfig
./conftest testconfig 2>&1 | grep ERROR > /dev/null
if [ $? = 0 ]
then
  echo "conftest ERROR: test $count. Expected no errors, got some."
  error=1
fi

count=7
rm -f testconfig
./conftest testconfig 2>&1 | grep ERROR > /dev/null
if [ $? != 0 ]
then
  echo "conftest ERROR: test $count. Expected config file not found error. "
  error=1
fi

if [ "$error" = 0 ]
then
  echo "conftest.sh.......Pass"
else
  echo "conftest.sh.......Fail"
fi

