/*
 * Copyright (c) 2003-2008 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

/*
   The datetest does the following:

   1. Generate 60 dates starting from the current date/time.
      The dates will be
      today + 30 days
      today + 60 days
      ...
      today + 1800 days

   2. For each date, create 3 formatted strings in the format below:
      Wed, 06 Oct 2002 12:43:03 GMT
      Wednesday, 06-Oct-02 12:43:03 GMT
      Wed Oct 6 12:43:03 2002

   3. Parse each formatted date.  Make sure the parsed date equals
      the correct date.

*/

#include <stdio.h>
#include <string.h>
#include <assert.h>
#include "date.h"


static const char* month[] = {
    "Jan", "Feb", "Mar", "Apr", "May", "Jun",
    "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
};

int main() {
    time_t curr, inc, end, result;
    struct tm date;
    char buf[128];

    printf("datetest..........");
    curr = time(NULL);
    inc = 60 * 60 * 24 * 30;  /* increment is one month */
    end = curr + inc * 60;

    while (curr < end) {
        gmtime_r(&curr, &date);

        sprintf(buf, "Wed, %d %s %d %.2d:%.2d:%.2d GMT",
                date.tm_mday, month[date.tm_mon], date.tm_year + 1900,
                date.tm_hour, date.tm_min, date.tm_sec);
        result = parse_date(buf, strlen(buf));
        assert(result == curr); 

        sprintf(buf, "Wednesday, %.2d-%s-%.2d %.2d:%.2d:%.2d GMT",
                date.tm_mday, month[date.tm_mon], date.tm_year % 100,
                date.tm_hour, date.tm_min, date.tm_sec);
        result = parse_date(buf, strlen(buf));
        assert(result == curr); 

        sprintf(buf, "Wed %s %d %.2d:%.2d:%.2d %d",
                month[date.tm_mon], date.tm_mday,
                date.tm_hour, date.tm_min, date.tm_sec,
                date.tm_year + 1900);
        result = parse_date(buf, strlen(buf));
        assert(result == curr); 

        curr = curr + inc;
    }

    sprintf(buf, "Pam Jon %d %.2d:%.2d:%.2d %d",
            date.tm_mday,
            date.tm_hour, date.tm_min, date.tm_sec,
            date.tm_year + 1900);
    result = parse_date(buf, strlen(buf));
    assert(result == -1); 

    printf("Pass\n");
    return 0; 
}


