/*
 * Copyright (c) 2003-2008 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef _GZIP_ENCODER_H_
#define _GZIP_ENCODER_H_

#include <zlib.h>
#include "buffer.h"
#include "pool.h"
#include "queue.h"


/* Pool of Gzip objects */
struct _GzipPool
{
    Pool gzencoders;    /* Pool of GzipEncoders */
    Pool gzmemory;      /* Pool of memory for gzip encoding */   
    int gzmemorysize;   /* Size of memory used for gzip encoding */
    int maxitems;       /* Maximum number of Gzip buffers to allocate */
    int freeitems;      /* Number of free Gzip buffers */
    Queue inq;          /* Queue of encoders waiting to do gzip_add() */
    Queue outq;         /* Queue of encoders finished with gzip_add() */
};
typedef struct _GzipPool GzipPool;

struct _GzipEncoder
{
    GzipPool *gzippool; /* Pointer to main GzipPool */
    z_stream zstream;   /* The internal gzip structure */
    Buffer *in;         /* The current input buffer */
    Buffer *out;        /* The current output buffer */
    char flushed;       /* True if the gzip buffer was flushed */
    char error;         /* True if an error occurred */
    char wroteheader;   /* True if we have written the gzip header */
    char wrotefooter;   /* True if we have written the gzip footer */
    uLong crc;          /* The CRC checksum of the input */
    char *memory;       /* Memory for gzip encoding */
    int currsize;       /* Current memory allocated */
    int total;          /* Total memory for allocation */
    void *connection;   /* Connection being compressed. */
};

typedef struct _GzipEncoder GzipEncoder;


void gzip_init(GzipPool *pool);
GzipEncoder* gzip_alloc(GzipPool *pool);
void gzip_free(GzipPool *pool, GzipEncoder *gz);
void gzip_add(GzipEncoder *gz, Buffer *input, void *connection);
int gzip_get_finished(GzipPool *pool, GzipEncoder **array, int len);
int gzip_has_output(GzipEncoder *gz);
void gzip_set_output(GzipEncoder *gz, Buffer *out);
void gzip_flush(GzipEncoder *gz);

#endif

