/*
 * Copyright (c) 2003-2009 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef _LOADBALANCER_H_
#define _LOADBALANCER_H_

#include <sys/socket.h>
#include "conf.h"
#include "sockets.h"
#include "log.h"
#include "buffer.h"


/* The load balancer */
struct _LoadBalancer { 
    Webserver *webservers;  /* List of web servers */
    int num_webservers;     /* Number of web servers */
    int num_down_servers;   /* Number of web servers marked down */
    ErrorLog *errorlog;     /* Used to notify when webserver go up/down */
    Sockets *sockets;       /* Used to send test connections to webservers */
    boolean has_hosts;      /* True if "webserver" options specify hosts */
};
typedef struct _LoadBalancer LoadBalancer;

void loadbalancer_init(LoadBalancer *b, Sockets *sockets, ErrorLog *errorlog,
                       Webserver *webservers, int count);

sockaddr_all* loadbalancer_getaddr(LoadBalancer *b, int id);

int loadbalancer_get_id(LoadBalancer *b, Substring host);

int loadbalancer_get_another_id(LoadBalancer *b, int id, Substring host);

boolean loadbalancer_is_valid(LoadBalancer *b, int id, Substring host);

boolean loadbalancer_is_server_down(LoadBalancer *b, int id);

void loadbalancer_connect_started(LoadBalancer *b, int id);

void loadbalancer_connect_done(LoadBalancer *b, int id, int error);

void loadbalancer_check_webservers(LoadBalancer *b);

#endif

