/*
 * Copyright (c) 2003-2008 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef _LOG_H_
#define _LOG_H_

#include <netinet/in.h>
#include <pthread.h>
#include "queue.h"
#include "pool.h"
#include "buffer.h"
#include "http.h"
#include "conf.h"

struct _AccessLog           /* The Access log file */  
{
    int fd;                 /* The file descriptor of the access log */
    const char *path;       /* The path to store the access log */
    long currentsize;       /* The current size (in bytes) of the log */
    Queue entries;          /* The queue of Buffers to write to the log */
    BufferPool entrypool;   /* The pool of Buffers */
    boolean doclose;        /* Whether to close the logfile */
    int queuesize;          /* The current size of the log entry queue */
    pthread_mutex_t poollock;  /* Lock used to access queuesize, entrypool */
    pthread_cond_t sizenotify; /* Condition used to notify when
                                  queue has free space */
};
typedef struct _AccessLog AccessLog;

struct _ErrorLog        /* The error log file */
{
    int fd;             /* The file descriptor of the error log */
    const char *path;   /* The path to store the error log in */
    long currentsize;   /* The current size (in bytes) of the log */
};
typedef struct _ErrorLog ErrorLog;

void accesslog_init(AccessLog *log, const char *path);
void accesslog_close(AccessLog *log);
void accesslog_write(AccessLog *log, HttpRequest *req, HttpReply *reply,
                     sockaddr_all *client, sockaddr_all *server,
                     unsigned long replysize, unsigned long pregzip_size, 
                     int iscachehit, int isrequesterr, int duration);

void errorlog_init(ErrorLog *log, const char *path);
void errorlog_close(ErrorLog *log);

void errorlog_printf(ErrorLog *log, sockaddr_all *client, const char *fmt, ...);
void errorlog_print(ErrorLog *log, sockaddr_all *client, 
                    const char *msg, int len);

#define DEBUG_PRINT if (Config.enable_debug) errorlog_print
#define DEBUG_PRINTF if (Config.enable_debug) errorlog_printf

#endif
 
