/*
 * Copyright (c) 2003-2008 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef _MQUEUE_H_
#define _MQUEUE_H_

#include <pthread.h>

struct _Queue {
    volatile int front;      /* The front of the queue */
    volatile int back;       /* The back of the queue */
    volatile int len;        /* The number of items in the queue */
    volatile int space;      /* The capacity of the queue */
    void** buf;              /* The actual queue items */
    pthread_mutex_t lock;    /* Lock for accessing queue */
    pthread_cond_t notify;   /* Condition to wait for Queue item */
};

typedef struct _Queue Queue;

void  queue_init(Queue *q, int size);
void  queue_add_fast(Queue *q, void *item);
void  queue_add(Queue *q, void *item);
void* queue_remove_wait(Queue *q);
int   queue_remove_many(Queue *q, void** items, int nitems);
int   queue_is_empty(Queue *q);
int   queue_length(Queue *q);

#endif
