/*
 * Copyright (c) 2003-2008 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

/**
  The queuetest will

  1. Create a queue of size 4
  2. Add 10 ints. Make sure the length is 10.
  3. Remove 10 ints one at a time.  Make sure the ints are correct.
  4. Add 10 ints.
  5. Remove 10 ints in a single function call.

**/

#include <unistd.h> 
#include <stdio.h>
#include <assert.h>
#include <stdlib.h>
#include "queue.h"

void* add_thread(void* arg)
{
    Queue *q = arg;
    int i;

    for (i = 0; i < 10; i++) {
        (void)usleep(5);
        queue_add(q, (void*) i);
    }

    (void) sleep(1);
    return NULL;
}

int main() {
    Queue *q;
    pthread_t tid;
    void* results[10];
    int i, n;

    printf("queuetest.........");
    q = (Queue *) malloc(sizeof(Queue));
    queue_init(q, 4);

    n = pthread_create(&tid, NULL, add_thread, q);
    assert(n == 0);

    for (i = 0; i < 10; i++) {
        n = (int) queue_remove_wait(q);
        assert(n == i);
    }

    for (i = 0; i < 10; i++) 
        queue_add_fast(q, (void*) i);

    assert(queue_length(q) == 10);
    for (i = 0; i < 10; i++) {
        queue_remove_many(q, (void **)results, 1);
        assert((int)(results[0]) == i);
    }
    printf("Pass\n");
    return 0;
}

