#! /bin/sh

# update_log_stats start/stop script
#
# Usage: update_log_stats.sh [start <dir>|stop|status]"
#       start <dir>:  Run a daemon to generate/update the log statistics 
#                     every hour. Store the log statistics in the given
#                     directory <dir>.
#       stop:         Stop the update_log_stats.sh daemon"
#       status:       Print whether update_log_stats.sh is running or not

basedir=/usr/local/vicompress
pidfile=$basedir/log/update_log_stats.pid
conffile=$basedir/etc/vicompress.conf
pid=""
user=""

accesslog=`cat $conffile | grep "^accesslog" | awk '{print $2}'`
user=`cat $conffile | grep "^user" | awk '{print $2}'`

if [ -f $pidfile ]
then
    pid=`cat $pidfile`
    result=`ps -ef | grep update | grep $pid | grep -v grep`
    if [ "$result" = "" ]
    then
        rm -f $pidfile
        pid=""
    fi
fi

case $1 in
start)
    dir=$2
    if [ "$dir" = "" ]
    then
        dir=$basedir/logstats
    fi

    if [ "$pid" != "" ]
    then
        echo "$0 start: update_log_stats (process $pid) already running"
        exit 0
    elif [ "$accesslog" = "" ]
    then
            echo "$0 Error: Cannot update logstats. accesslog not defined\
 in $conffile. "
            exit 1
    else
        # Copy template.html and verticalbar.png images 
        # to target directory if needed
        files="template.html verticalbar1.png verticalbar2.png \
               verticalbar3.png verticalbar4.png visolvelogo.gif"
        for file in `echo $files`;
        do
            if [ ! -f $dir/$file ]
            then
                cp $basedir/logstats/$file $dir/$file
                if [ $? != 0 ]
                then
                    echo "$0 Error: Cannot copy $basedir/logstats/$file \
to $dir/$file"
                    exit 1
                fi
            fi
        done

        $basedir/bin/update_log_stats $accesslog $dir 1
        pid=`ps -ef | grep "update_log_stats " | grep -v grep | awk '{print $2}'`
        echo $pid > $pidfile
        echo "update_log_stats started"
        echo "The HTML statistics will be saved to directory $dir"
        exit 0
    fi
    ;;
stop)
    if [ "$pid" != "" ]
    then
        kill -INT $pid
        rm -f $pidfile
        echo "$0 stop: update_log_stats.sh pid $pid has stopped"
    fi
    ;;
status)
    if [ "$pid" != "" ]
    then
        echo "update_log_stats.sh is running, pid $pid"
    else
        echo "update_log_stats.sh is not running"
    fi
    ;;
*)
    echo "Usage: update_log_stats.sh [start <dir>|stop|status]"
    echo "    start <dir>:  Run a daemon to generate/update the log statistics" 
    echo "                  every hour. Store the log statistics in the given"
    echo "                  directory <dir>."
    echo "    stop:         Stop the update_log_stats.sh daemon"
    echo "    status:       Print whether update_log_stats.sh is running or not"
    exit 2

esac


