#!/bin/sh

# Vicompress server start/stop script
#
# Usage: vicompress.sh [start|stop|status|debug]
#    start:   Start the vicompress server
#    stop:    Stop the vicompress server
#    status:  Check whether vicompress is running or not
#    debug:   Enable/disable debug messages in the errorlog
#
# See vicompress.conf for configuration options
#
# Put this in /etc/init.d or /etc/rc3.d/ to start vicompress
# at boot time 

basedir=/usr/local/vicompress
pidfile=/var/run/vicompress.pid
server=$basedir/bin/vicompress
conffile=$basedir/etc/vicompress.conf
pid=""

if [ -f $pidfile ]
then
    pid=`cat $pidfile`
    result=`ps -ef | grep vicom | grep $pid | grep -v grep`
    if [ "$result" = "" ]
    then
        rm -f $pidfile
        pid=""
    fi
fi

case $1 in 
start)
    if [ "$pid" != "" ]
    then
        
        echo "$0 start: vicompress (pid $pid) already running"
        exit 0
    else
        # Increase maximum file descriptors if possible
        user=`whoami`
        nfile=`ulimit -n`

        if [ "$user" = "root" ]
        then
            $basedir/bin/tune_kernel.sh
        fi
        if [ "$user" = "root" -a "$nfile" -lt 8192 ]
        then
            ulimit -n 8192 > /dev/null 2>&1
        fi

        $server $conffile
        result=$? 
        if [ $result = 0 ]
        then
            echo "$0 start: vicompress started" 
        else
            echo "$0 start: Error starting vicompress"
            exit 1
        fi
    fi
    ;;
stop)
    if [ "$pid" != "" ]
    then
        kill -INT $pid
        rm -f $pidfile
        echo "$0 stop: vicompress pid $pid has stopped"
    fi
    ;;
status)
    if [ "$pid" != "" ]
    then
        echo "Vicompress is running, pid $pid"
    else
        echo "Vicompress is not running"
    fi
    ;;
debug)
    if [ "$pid" != "" ]
    then
        kill -USR1 $pid
    else
        echo "Vicompress must first be running to enable/disable debugging"
    fi
    ;;
*)
    echo "Usage: $0 [start|stop|status|debug]"
    echo "   start:   Start the vicompress server"
    echo "   stop:    Stop the vicompress server"
    echo "   status:  Check whether vicompress is running or not"
    echo "   debug:   Enable/disable debug messages in the errorlog"
    echo ""
    echo "See $conffile for configuration options"
    exit 2
esac

