/*
 * Copyright (c) 2003-2008 Visolve
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef _VICOMPRESS_WIN32_H_
#define _VICOMPRESS_WIN32_H_

#ifdef WIN32

/* This file (along with win32.c) contains an implementation
 * of cygwin functions used by vicompress, so that we don't have
 * a dependency on cygwin.dll at runtime.
 */
#include <netinet/in.h>

/* Signals */
#undef SIGINT
#undef SIGTERM
#define SIGINT    2
#define SIGTERM  15

/* File I/O */

#undef S_IFDIR
#define S_IFDIR 0040000

struct win_stat {
    unsigned int st_dev;
    unsigned short st_ino;
    unsigned short st_mode;
    short st_nlink;
    short st_uid;
    short st_gid;
    unsigned int st_rdev;
    long st_size;
    long st_atimme;
    long st_mtimme;
    long st_ctimme;
};

int win_open(const char *name, int flags, ...);
int win_stat(const char *name, struct win_stat *info);
void* win_fopen(const char *name, char *mode);
void win_fprintf(void *fp, const char *fmt, ...);

#undef O_CREAT
#undef O_TRUNC
#undef O_BINARY

#define O_CREAT  0x0100
#define O_TRUNC  0x0200

#define open     win_open
#define fopen    win_fopen
#define stat     win_stat
#define fprintf  win_fprintf
#undef  stderr
#define stderr  (fdopen(2, "w"))

/* Socket functions */
void winsock_init();
int win_socket(int af, int type, int proto);
int win_listen(int fd, int backlog);
int win_bind(int fd, const struct sockaddr *addr, int addrlen);
int win_accept(int listenfd, struct sockaddr *addr, int* addrlen);
int win_connect(int fd, struct sockaddr *addr, int addrlen);
int win_recv(int fd, char *buf, int amount, int flags);
int win_send(int fd, char *buf, int amount, int flags);
int win_shutdown(int fd, int how);
int win_fcntl(int fd, int cmd, int arg);
int win_getsockopt(int fd, int level, int optname, void *optval, int *optlen);
int win_setsockopt(int fd, int level, int optname, void *optval, int optlen);
struct hostent* win_gethostbyname(const char *name);
int win_close(int fd);
int win_gethostname(char *name, int namelen);
unsigned long  win_inet_addr(const char *addr);
unsigned short win_htons(unsigned short);
unsigned short win_ntohs(unsigned short);

extern int* win_errno;
#undef errno
#define errno      *win_errno
#define socket     win_socket
#define listen     win_listen
#define bind       win_bind
#define accept     win_accept
#define connect    win_connect
#define recv       win_recv
#define send       win_send
#define shutdown   win_shutdown
#define fcntl      win_fcntl
#define getsockopt win_getsockopt
#define setsockopt win_setsockopt
#define gethostbyname win_gethostbyname
#define gethostname win_gethostname
#define fcntl      win_fcntl
#define inet_addr  win_inet_addr
#define htons      win_htons
#define ntohs      win_ntohs

/* WinSock error codes */
#undef EINTR
#define EINTR            10004
#undef EMFILE
#define EMFILE           10024
#undef EWOULDBLOCK
#define EWOULDBLOCK      10035
#undef EINPROGRESS
#define EINPROGRESS      10036
#undef EALREADY
#define EALREADY         10037
#undef EADDRINUSE
#define EADDRINUSE       10048
#undef EADDRNOTAVAIL
#define EADDRNOTAVAIL    10049
#undef EISCONN
#define EISCONN          10056
#undef ETIMEDOUT
#define ETIMEDOUT        10060

/* Misc */
int win_isdigit(char c);
#undef isdigit
#define isdigit(c) win_isdigit(c)

void service_running();
int install_service(const char *dir);
int uninstall_service();
int win_get_num_cpus();

#endif /* WIN32 */

#endif /* _VICOMPRESS_WIN32_H_ */


